@@ -5,6 +5,7 @@ import time
 import os
 import sys
 import traceback
+import types
 
 from multiprocessing import current_process
 from multiprocessing import util as mputil
@@ -33,18 +34,28 @@ class ColorFormatter(logging.Formatter):
         logging.Formatter.__init__(self, msg)
         self.use_color = use_color
 
+    def formatException(self, ei):
+        r = logging.Formatter.formatException(self, ei)
+        if type(r) in [types.StringType]:
+            r = r.decode('utf-8', 'replace')    # convert to unicode
+        return r
+
     def format(self, record):
         levelname = record.levelname
 
         if self.use_color and levelname in COLORS:
-            record.msg = str(colored().names[COLORS[levelname]](record.msg))
+            record.msg = unicode(colored().names[COLORS[levelname]](
+                            record.msg))
 
         # Very ugly, but have to make sure processName is supported
         # by foreign logger instances.
         # (processName is always supported by Python 2.7)
         if "processName" not in record.__dict__:
             record.__dict__["processName"] = current_process()._name
-        return logging.Formatter.format(self, record)
+        t = logging.Formatter.format(self, record)
+        if type(t) in [types.UnicodeType]:
+            t = t.encode('utf-8', 'replace')
+        return t
 
 
 def get_task_logger(loglevel=None, name=None):
@@ -83,6 +94,8 @@ def setup_logging_subsystem(loglevel=conf.CELERYD_LOG_LEVEL, logfile=None,
 def _detect_handler(logfile=None):
     """Create log handler with either a filename, an open stream
     or ``None`` (stderr)."""
+    if logfile is None:
+        logfile = sys.__stderr__
     if not logfile or hasattr(logfile, "write"):
         return logging.StreamHandler(logfile)
     return logging.FileHandler(logfile)
@@ -118,7 +131,7 @@ def setup_logger(loglevel=conf.CELERYD_LOG_LEVEL, logfile=None,
 
 def setup_task_logger(loglevel=conf.CELERYD_LOG_LEVEL, logfile=None,
         format=conf.CELERYD_TASK_LOG_FORMAT, colorize=conf.CELERYD_LOG_COLOR,
-        task_kwargs=None, **kwargs):
+        task_kwargs=None, propagate=False, **kwargs):
     """Setup the task logger. If ``logfile`` is not specified, then
     ``stderr`` is used.
 
@@ -132,12 +145,13 @@ def setup_task_logger(loglevel=conf.CELERYD_LOG_LEVEL, logfile=None,
     task_kwargs.setdefault("task_name", "-?-")
     logger = _setup_logger(get_task_logger(loglevel, task_name),
                             logfile, format, colorize, **kwargs)
+    logger.propagate = int(propagate)   # this is an int for some reason.
+                                        # better to just not question why.
     return LoggerAdapter(logger, task_kwargs)
 
 
 def _setup_logger(logger, logfile, format, colorize,
         formatter=ColorFormatter, **kwargs):
-
     if logger.handlers:                 # already configured
         return logger
 
