@@ -9,6 +9,7 @@ import atexit
 
 from django.core.exceptions import ImproperlyConfigured
 
+
 @atexit.register
 def _display_help():
     import sys
@@ -21,7 +22,11 @@ ERROR: celery can't be added to INSTALLED_APPS anymore
 
 Please install the django-celery package and add:
 
-    INSTALLED_APPS = "djcelery"
+    import djcelery
+    djcelery.setup_loader()
+    INSTALLED_APPS = ("djcelery", )
+
+to settings.py.
 
 To install django-celery you can do one of the following:
 
@@ -44,7 +49,7 @@ To install django-celery you can do one of the following:
 
 If you weren't aware of this already you should read the
 Celery 2.0 Changelog as well:
-    http://github.com/ask/celery/tree/djangofree/Changelog
+    http://celeryproject.org/docs/changelog.html
 
 """)
 
