@@ -102,11 +102,6 @@ class test_inspect(unittest.TestCase):
         self.i.disable_events()
         self.assertIn("disable_events", MockBroadcastPublisher.sent)
 
-    @with_mock_broadcast
-    def test_diagnose(self):
-        self.i.diagnose()
-        self.assertIn("diagnose", MockBroadcastPublisher.sent)
-
     @with_mock_broadcast
     def test_ping(self):
         self.i.ping()
